pub fn color_log(level: &Level) -> ColoredStringExpand description
Make sure that the loglevel is in color, even though not using pretty_env logger
pub fn color_log(level: &Level) -> ColoredStringMake sure that the loglevel is in color, even though not using pretty_env logger